==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/EndpointAccessProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs.builder
import com.pulumi.azurenative.batch.kotlin.enums.EndpointAccessDefaultAction
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network access profile for Batch endpoint.
 * @property defaultAction Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
 * @property ipRules Array of IP ranges to filter client IP address.
 */
public data class EndpointAccessProfileArgs(
    public val defaultAction: Output<EndpointAccessDefaultAction>,
    public val ipRules: Output<List<IPRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs =
        com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs.builder()
            .defaultAction(defaultAction.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipRules(
                ipRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [EndpointAccessProfileArgs].
 */
@PulumiTagMarker
public class EndpointAccessProfileArgsBuilder internal constructor() {
    private var defaultAction: Output<EndpointAccessDefaultAction>? = null

    private var ipRules: Output<List<IPRuleArgs>>? = null

    /**
     * @param value Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
     */
    @JvmName("rkxsabvkwkakbcbp")
    public suspend fun defaultAction(`value`: Output<EndpointAccessDefaultAction>) {
        this.defaultAction = value
    }

    /**
     * @param value Array of IP ranges to filter client IP address.
     */
    @JvmName("bqyvicrtuulqenlt")
    public suspend fun ipRules(`value`: Output<List<IPRuleArgs>>) {
        this.ipRules = value
    }

    @JvmName("jpsgqtpnclsremwi")
    public suspend fun ipRules(vararg values: Output<IPRuleArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values Array of IP ranges to filter client IP address.
     */
    @JvmName("uqxuuvugajaeiwws")
    public suspend fun ipRules(values: List<Output<IPRuleArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
     */
    @JvmName("xnfdalkjitfrustx")
    public suspend fun defaultAction(`value`: EndpointAccessDefaultAction) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Array of IP ranges to filter client IP address.
     */
    @JvmName("yjjklvnmpsveyphh")
    public suspend fun ipRules(`value`: List<IPRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("jmtlircylgyarakl")
    public suspend fun ipRules(argument: List<suspend IPRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("wjoapklmjihmtoiu")
    public suspend fun ipRules(vararg argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("acoyoksnmrjrkycn")
    public suspend fun ipRules(argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values Array of IP ranges to filter client IP address.
     */
    @JvmName("lhxfsamybxtipvdh")
    public suspend fun ipRules(vararg values: IPRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    internal fun build(): EndpointAccessProfileArgs = EndpointAccessProfileArgs(
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/batch/kotlin/inputs/EndpointAccessProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.batch.kotlin.inputs

import com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs.builder
import com.pulumi.azurenative.batch.kotlin.enums.EndpointAccessDefaultAction
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Network access profile for Batch endpoint.
 * @property defaultAction Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
 * @property ipRules Array of IP ranges to filter client IP address.
 */
public data class EndpointAccessProfileArgs(
    public val defaultAction: Output<EndpointAccessDefaultAction>,
    public val ipRules: Output<List<IPRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs =
        com.pulumi.azurenative.batch.inputs.EndpointAccessProfileArgs.builder()
            .defaultAction(defaultAction.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipRules(
                ipRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [EndpointAccessProfileArgs].
 */
@PulumiTagMarker
public class EndpointAccessProfileArgsBuilder internal constructor() {
    private var defaultAction: Output<EndpointAccessDefaultAction>? = null

    private var ipRules: Output<List<IPRuleArgs>>? = null

    /**
     * @param value Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
     */
    @JvmName("uhrxjxcekrevkxul")
    public suspend fun defaultAction(`value`: Output<EndpointAccessDefaultAction>) {
        this.defaultAction = value
    }

    /**
     * @param value Array of IP ranges to filter client IP address.
     */
    @JvmName("leegawabwkibyoao")
    public suspend fun ipRules(`value`: Output<List<IPRuleArgs>>) {
        this.ipRules = value
    }

    @JvmName("tpevrihpgtdrnbml")
    public suspend fun ipRules(vararg values: Output<IPRuleArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values Array of IP ranges to filter client IP address.
     */
    @JvmName("scfhvdalcqaksprl")
    public suspend fun ipRules(values: List<Output<IPRuleArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Default action for endpoint access. It is only applicable when publicNetworkAccess is enabled.
     */
    @JvmName("jubujfwjifhgkrff")
    public suspend fun defaultAction(`value`: EndpointAccessDefaultAction) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Array of IP ranges to filter client IP address.
     */
    @JvmName("dkfmmcffihvrtdvl")
    public suspend fun ipRules(`value`: List<IPRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("rsghmymytkprmxpl")
    public suspend fun ipRules(argument: List<suspend IPRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("bwyxbcsbjfgwvyls")
    public suspend fun ipRules(vararg argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument Array of IP ranges to filter client IP address.
     */
    @JvmName("ohmxocigflnitbhs")
    public suspend fun ipRules(argument: suspend IPRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values Array of IP ranges to filter client IP address.
     */
    @JvmName("iiqhuggknywpnnbg")
    public suspend fun ipRules(vararg values: IPRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    internal fun build(): EndpointAccessProfileArgs = EndpointAccessProfileArgs(
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules,
    )
}
